@@ -1,22 +1,9 @@
 /*
-  Copyright (C) 2002 Rik Hemsley (rikkus) <rik@kde.org>
-  Copyright (C) 2002 Benjamin Meyer <ben-devel@meyerhome.net>
-  CopyRight (C) 2002 Nadeem Hasan <nhasan@kde.org>
+    SPDX-FileCopyrightText: 2002 Rik Hemsley (rikkus) <rik@kde.org>
+    SPDX-FileCopyrightText: 2002 Benjamin Meyer <ben-devel@meyerhome.net>
+    SPDX-FileCopyrightText: 2002 Nadeem Hasan <nhasan@kde.org>
 
-  This library is free software; you can redistribute it and/or
-  modify it under the terms of the GNU Library General Public
-  License as published by the Free Software Foundation; either
-  version 2 of the License, or (at your option) any later version.
-
-  This library is distributed in the hope that it will be useful,
-  but WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-  Library General Public License for more details.
-
-  You should have received a copy of the GNU Library General Public License
-  along with this library; see the file COPYING.LIB.  If not, write to
-  the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-  Boston, MA 02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "cddb.h"
@@ -24,7 +11,7 @@
 #include "categories.h"
 #include "kcddbi18n.h"
 
-#include <KCoreAddons/KStringHandler>
+#include <KStringHandler>
 
 #include <QDebug>
 #include <QStringList>
@@ -129,8 +116,7 @@ namespace KCDDB
     for (QStringList::const_iterator cddbCacheDir = cddbCacheDirs.constBegin();
         cddbCacheDir != cddbCacheDirs.constEnd(); ++cddbCacheDir)
     {
-      foreach(const QString &category, categories)
-      {
+      for (const QString &category : qAsConst(categories)) {
         QFile f( *cddbCacheDir + QLatin1Char( '/' ) + category + QLatin1Char( '/' ) + trackOffsetListToId(offsetList) );
         if ( f.exists() && f.open(QIODevice::ReadOnly) )
         {
